.. -*- mode: rst -*-

|Azure|_ |Travis|_ |rtd|_ |Codecov|_

|python_version|_ |pypi_version|_ |anaconda_cloud|_

|gitter|_ |DOI|_

.. |Azure| image:: https://dev.azure.com/franciscode-la-pena-manchon/hyperspy/_apis/build/status/hyperspy.hyperspy?branchName=RELEASE_next_minor
.. _Azure: https://dev.azure.com/franciscode-la-pena-manchon/hyperspy/_build?definitionId=1&_a=summary&view=branches

.. |Travis| image:: https://api.travis-ci.org/hyperspy/hyperspy.png?branch=RELEASE_next_minor
.. _Travis: https://travis-ci.org/hyperspy/hyperspy

.. |Codecov| image:: https://codecov.io/gh/hyperspy/hyperspy/branch/RELEASE_next_minor/graph/badge.svg
.. _Codecov: https://codecov.io/gh/hyperspy/hyperspy

.. |rtd| image:: https://readthedocs.org/projects/hyperspy/badge/?version=latest
.. _rtd: https://readthedocs.org/projects/hyperspy/?badge=latest

.. |pypi_version| image:: http://img.shields.io/pypi/v/hyperspy.svg?style=flat
.. _pypi_version: https://pypi.python.org/pypi/hyperspy

.. |anaconda_cloud| image:: https://anaconda.org/conda-forge/hyperspy/badges/version.svg
.. _anaconda_cloud: https://anaconda.org/conda-forge/hyperspy

.. |python_version| image:: https://img.shields.io/pypi/pyversions/hyperspy.svg?style=flat
.. _python_version: https://pypi.python.org/pypi/hyperspy

.. |gitter| image:: https://badges.gitter.im/Join%20Chat.svg
.. _gitter: https://gitter.im/hyperspy/hyperspy?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

.. |DOI| image:: https://zenodo.org/badge/2233998.svg
.. _DOI: https://zenodo.org/badge/latestdoi/2233998


HyperSpy is an open source Python library for the interactive analysis of
multidimensional datasets that can be described as multidimensional arrays
of a given signal (for example, a 2D array of spectra, also known as a
spectrum image).

HyperSpy makes it straightforward to apply analytical procedures that
operate on an individual signal to multidimensional arrays, as well as
providing easy access to analytical tools that exploit the multidimensionality
of the dataset.

Its modular structure makes it easy to add features to analyze many different
types of signals.

HyperSpy is released under the GPL v3 license.

**Since version 0.8.4, HyperSpy only supports Python 3.** If you need to install
HyperSpy in Python 2.7, please install version 0.8.3.

Contributing
------------

Everyone is welcome to contribute. Please read our
`contributing guidelines <https://github.com/hyperspy/hyperspy/blob/RELEASE_next_minor/.github/CONTRIBUTING.md>`_ and get started!


